``eradiate.attrs``
==================

.. automodule:: eradiate.attrs

.. py:currentmodule:: eradiate.attrs

Attributes
----------

.. autodata:: AUTO
   :annotation:

.. autodata:: AutoType
   :annotation:

Attribute docs extension
------------------------

.. autofunction:: parse_docs

.. autofunction:: documented

.. autofunction:: get_doc
